==> kendo-vue-dialogs-5.1.0.tgz: package/README.md <==
<a href="https://www.telerik.com/kendo-vue-ui/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs&utm_content=banner" target="_blank">
<img src="https://www.telerik.com/kendo-vue-ui/npm-banner.svg" alt="Kendo UI for Vue NPM Banner">
</a>


## Kendo UI for Vue Dialogs for Vue (Dialog and Window Component)	

> **Important**
> * This package is а part of [Kendo UI for Vue](https://www.telerik.com/kendo-vue-ui/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)&mdash;a commercial UI library.
> * You will need to install a license key when adding the package to your project. For more information, please refer to the [Kendo UI for Vue My License page](https://www.telerik.com/kendo-vue-ui/my-license/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs).
> * To receive a license key, you need to either [purchase a license](https://www.telerik.com/purchase/kendo-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs) or register for a [free trial](https://www.telerik.com/download-login-v2-kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs). Doing so indicates that you [accept the Kendo UI for Vue License Agreement](https://www.telerik.com/purchase/license-agreement/kendo-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs).
> * The 30-day free trial gives you access to all the Kendo UI for Vue components and their full functionality. Additionally, for the period of your license, you get access to our legendary technical support provided directly by the Kendo UI for Vue dev team!
>
> [Start using Kendo UI for Vue](https://www.telerik.com/download-login-v2-kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs) and speed up your development process!

The Kendo UI for Vue Dialogs are UI components for prompting user interaction. They provide modal and non-modal windows for showing additional information to the user, filling a form and many others.	
The Kendo UI for Vue Dialogs package includes the following components:	

* [Dialog component](https://www.telerik.com/kendo-vue-ui/components/dialogs/dialog/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)
* [Window component](https://www.telerik.com/kendo-vue-ui/components/dialogs/window/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)	

## Vue Dialogs	

> Historically, all Kendo UI for Vue Native components support both **Vue 2** and **Vue 3**, however, Vue 2 is currently in its end-of-support phase till Nov 2024. After our last major release for 2024, Vue 2 will no longer be supported in the new versions of the Kendo UI for Vue components. Please check our [Vue 2 End of Support article](https://www.telerik.com/kendo-vue-ui/components/vue2-deprecation/) for more details.

Among the many features which the Kendo UI for Vue Dialogs deliver are:

* **Modal**&mdash;The dialogs can be shown as modal on the page to prevent the user from interacting with other elements on the page.
* **Resizing**&mdash;You can resize the window to change its dimensions to better view a large content.
* **Dragging**&mdash;The window can be dragged across the page, to position it at a specific part of the page.
* **Keyboard navigation**&mdash;The Dialogs can be controlled by the keyboard.
* **Title and content**&mdash;You have full control over what is rendered in the dialogs title and content.
* [**Theme support**](https://www.telerik.com/kendo-vue-ui/components/styling/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)&mdash;The Kendo UI for Vue Dialogs, as well as all 80+ components in the Kendo UI for Vue suite, are styled in four polished themes (Bootstrap, Material, Default and Fluent) and can be further customized to match your specific design guidelines.	

## Support Options	

For any issues you might encounter while working with the Kendo UI for Vue Dialogs, use any of the available support channels:	

* Industry-leading technical support&mdash;Kendo UI for Vue paid license holders and users with an active (free) trial license can take advantage of our outstanding customer support. To submit a ticket, use [the dedicated Kendo UI for Vue support system](https://www.telerik.com/account/support-tickets?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-all).	
* Product forums&mdash;The [Kendo UI for Vue forums](https://www.telerik.com/forums/kendo-ui-vue?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-all) are part of the free support you can get from the community and from the Kendo UI for Vue team.	
* Feedback portal&mdash;The [Kendo UI for Vue feedback portal](https://feedback.telerik.com/kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-all) is where you can request and vote for new features to be added.	

## Resources	

* [Getting Started with Kendo UI for Vue](https://www.telerik.com/kendo-vue-ui/getting-started/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)	
* [Getting Started with the Kendo UI for Vue Dialogs](https://www.telerik.com/kendo-vue-ui/components/dialogs/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)	
* [API Reference of the Kendo UI for Vue Dialogs](https://www.telerik.com/kendo-vue-ui/components/dialogs/api/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)	
* [Kendo UI for Vue Roadmap](https://www.telerik.com/kendo-vue-ui/roadmap/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)	
* [Blogs](https://www.telerik.com/blogs/tag/vue?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)	
* [Demos, documentation, and component reference](https://www.telerik.com/kendo-vue-ui/components/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)	
* [Kendo UI for Vue pricing and licensing](https://www.telerik.com/purchase/kendo-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)	

*Copyright © 2023 Progress Software Corporation and/or its subsidiaries or affiliates. All Rights Reserved.*	

*Progress, Telerik, and certain product names used herein are trademarks or registered trademarks of Progress Software Corporation and/or one of its subsidiaries or affiliates in the U.S. and/or other countries.*

==> kendo-vue-dialogs-6.0.1.tgz: package/README.md <==
<a href="https://www.telerik.com/kendo-vue-ui/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs&utm_content=banner" target="_blank">
<img src="https://www.telerik.com/kendo-vue-ui/npm-banner.svg" alt="Kendo UI for Vue NPM Banner">
</a>


## Kendo UI for Vue Dialogs Package

> **Important**
> * This package is а part of [Kendo UI for Vue](https://www.telerik.com/kendo-vue-ui/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)&mdash;a commercial UI library.
> * You will need to install a license key when adding the package to your project. For more information, please refer to the [Kendo UI for Vue My License page](https://www.telerik.com/kendo-vue-ui/my-license/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs).
> * To receive a license key, you need to either [purchase a license](https://www.telerik.com/purchase/kendo-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs) or register for a [free trial](https://www.telerik.com/download-login-v2-kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs). Doing so indicates that you [accept the Kendo UI for Vue License Agreement](https://www.telerik.com/purchase/license-agreement/kendo-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs).
> * The 30-day free trial gives you access to all the Kendo UI for Vue components and their full functionality. Additionally, for the period of your license, you get access to our legendary technical support provided directly by the Kendo UI for Vue dev team!
>
> [Start using Kendo UI for Vue](https://www.telerik.com/download-login-v2-kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs) and speed up your development process!

The Kendo UI for Vue Dialogs are UI components for prompting user interaction. They provide modal and non-modal windows for showing additional information to the user, filling a form and many others.
The Kendo UI for Vue Dialogs package includes the following components:

* [Dialog component](https://www.telerik.com/kendo-vue-ui/components/dialogs/dialog/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)
* [Window component](https://www.telerik.com/kendo-vue-ui/components/dialogs/window/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)

## Vue Dialogs

> Starting with **version 6.0.0**, Kendo UI for Vue Native components no longer support Vue 2. Please check our [Vue 2 End of Support article](https://www.telerik.com/kendo-vue-ui/components/vue2-deprecation/) for more details.

Among the many features which the Kendo UI for Vue Dialogs deliver are:

* **Modal**&mdash;The dialogs can be shown as modal on the page to prevent the user from interacting with other elements on the page.
* **Resizing**&mdash;You can resize the window to change its dimensions to better view a large content.
* **Dragging**&mdash;The window can be dragged across the page, to position it at a specific part of the page.
* **Keyboard navigation**&mdash;The Dialogs can be controlled by the keyboard.
* **Title and content**&mdash;You have full control over what is rendered in the dialogs title and content.
* [**Theme support**](https://www.telerik.com/kendo-vue-ui/components/styling/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)&mdash;The Kendo UI for Vue Dialogs, as well as all 80+ components in the Kendo UI for Vue suite, are styled in four polished themes (Bootstrap, Material, Default and Fluent) and can be further customized to match your specific design guidelines.

## Support Options

For any issues you might encounter while working with the Kendo UI for Vue Dialogs, use any of the available support channels:

* Industry-leading technical support&mdash;Kendo UI for Vue paid license holders and users with an active (free) trial license can take advantage of our outstanding customer support. To submit a ticket, use [the dedicated Kendo UI for Vue support system](https://www.telerik.com/account/support-tickets?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-all).
* Product forums&mdash;The [Kendo UI for Vue forums](https://www.telerik.com/forums/kendo-ui-vue?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-all) are part of the free support you can get from the community and from the Kendo UI for Vue team.
* Feedback portal&mdash;The [Kendo UI for Vue feedback portal](https://feedback.telerik.com/kendo-vue-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-all) is where you can request and vote for new features to be added.

## Resources

* [Getting Started with Kendo UI for Vue](https://www.telerik.com/kendo-vue-ui/getting-started/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)
* [Getting Started with the Kendo UI for Vue Dialogs](https://www.telerik.com/kendo-vue-ui/components/dialogs/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)
* [API Reference of the Kendo UI for Vue Dialogs](https://www.telerik.com/kendo-vue-ui/components/dialogs/api/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)
* [Kendo UI for Vue Roadmap](https://www.telerik.com/kendo-vue-ui/roadmap/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)
* [Blogs](https://www.telerik.com/blogs/tag/vue?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)
* [Demos, documentation, and component reference](https://www.telerik.com/kendo-vue-ui/components/?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)
* [Kendo UI for Vue pricing and licensing](https://www.telerik.com/purchase/kendo-ui?utm_medium=referral&utm_source=npm&utm_campaign=kendo-ui-vue-trial-npm-dialogs)

*Copyright © 2024 Progress Software Corporation and/or its subsidiaries or affiliates. All Rights Reserved.*

*Progress, Telerik, and certain product names used herein are trademarks or registered trademarks of Progress Software Corporation and/or one of its subsidiaries or affiliates in the U.S. and/or other countries.*
